==> kadu_1.1.orig.tar.bz2: kadu-1.1/kadu-core/gui/widgets/chat-edit-widget.cpp <==
/*
 * %kadu copyright begin%
 * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
 * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
 * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
 * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
 * %kadu copyright end%
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "gui/widgets/simple-configuration-value-state-notifier.h"

#include "chat-edit-widget.h"

ChatEditWidget::ChatEditWidget(Chat chat, QWidget *parent) :
		ModalConfigurationWidget(parent), StateNotifier{new SimpleConfigurationValueStateNotifier{this}}, MyChat(chat)
{
}

ChatEditWidget::~ChatEditWidget()
{
}

Chat ChatEditWidget::chat()
{
	return MyChat;
}

SimpleConfigurationValueStateNotifier * ChatEditWidget::simpleStateNotifier() const
{
	return StateNotifier;
}

const ConfigurationValueStateNotifier * ChatEditWidget::stateNotifier() const
{
	return StateNotifier;
}

==> kadu-2.1.tar.bz2: kadu-2.1/kadu-core/gui/widgets/chat-edit-widget.cpp <==
/*
 * %kadu copyright begin%
 * Copyright 2009 Wojciech Treter (juzefwt@gmail.com)
 * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
 * Copyright 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
 * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
 * %kadu copyright end%
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "gui/widgets/simple-configuration-value-state-notifier.h"

#include "chat-edit-widget.h"

ChatEditWidget::ChatEditWidget(Chat chat, QWidget *parent) :
		ModalConfigurationWidget{parent},
		m_stateNotifier{make_owned<SimpleConfigurationValueStateNotifier>(this)},
		m_chat{chat}
{
}

ChatEditWidget::~ChatEditWidget()
{
}

Chat ChatEditWidget::chat() const
{
	return m_chat;
}

SimpleConfigurationValueStateNotifier * ChatEditWidget::simpleStateNotifier() const
{
	return m_stateNotifier.get();
}

const ConfigurationValueStateNotifier * ChatEditWidget::stateNotifier() const
{
	return m_stateNotifier.get();
}
